pub enum Sidecar {
Simple {
location_key: LocationKey,
future_expr: Box<Expr>,
},
Bidi {
location_key: LocationKey,
sidecar_id: SidecarId,
sidecar_closure: Box<Expr>,
},
}Expand description
A compile-time directive to spawn a future on a location’s LocalSet
alongside the DFIR scheduler.
Variants
Simple
A ready-to-go future expression (e.g. telemetry metrics collection).
Bidi
A user-owned sidecar that returns a (Stream, Sink) pair to the framework.
The closure is called at startup; the returned stream feeds items into the
dataflow and the returned sink receives items from the dataflow.