pub struct BuiltFlow<'a> { /* private fields */ }Available on crate feature
build only.Implementations
Sourceimpl<'a> BuiltFlow<'a>
impl<'a> BuiltFlow<'a>
Sourcepub fn ir_json(&self) -> Result<String, Error>
Available on crate feature runtime_support only.
pub fn ir_json(&self) -> Result<String, Error>
runtime_support only.Serialize the IR as JSON.
Sourcepub fn location_names(&self) -> &SecondaryMap<LocationKey, String>
pub fn location_names(&self) -> &SecondaryMap<LocationKey, String>
Returns all raw location ID -> location name mappings.
Sourcepub fn graph_api(&self) -> GraphApi<'_>
Available on stageleft_runtime and crate feature viz only.
pub fn graph_api(&self) -> GraphApi<'_>
stageleft_runtime and crate feature viz only.Get a GraphApi instance for this built flow
Sourcepub fn render_graph(
&self,
format: GraphType,
use_short_labels: bool,
show_metadata: bool,
) -> String
Available on crate feature viz only.
pub fn render_graph( &self, format: GraphType, use_short_labels: bool, show_metadata: bool, ) -> String
viz only.Render graph to string in the given format.
Sourcepub fn write_graph_to_file(
&self,
format: GraphType,
filename: &str,
use_short_labels: bool,
show_metadata: bool,
) -> Result<(), Box<dyn Error>>
Available on crate feature viz only.
pub fn write_graph_to_file( &self, format: GraphType, filename: &str, use_short_labels: bool, show_metadata: bool, ) -> Result<(), Box<dyn Error>>
viz only.Write graph to file.
Sourcepub fn generate_graph(
&self,
config: &GraphConfig,
) -> Result<Option<String>, Box<dyn Error>>
Available on crate feature viz only.
pub fn generate_graph( &self, config: &GraphConfig, ) -> Result<Option<String>, Box<dyn Error>>
viz only.Generate graph based on CLI config. Returns Some(path) if written.
pub fn optimize_with(self, f: impl FnOnce(&mut [HydroRoot])) -> Self
pub fn with_default_optimize<D: Deploy<'a>>(self) -> DeployFlow<'a, D>
Sourcepub fn sim(self) -> SimFlow<'a>
Available on crate feature sim only.
pub fn sim(self) -> SimFlow<'a>
sim only.Creates a simulation for this builder, which can be used to run deterministic simulations of the Hydro program.
pub fn into_deploy<D: Deploy<'a>>(self) -> DeployFlow<'a, D>
pub fn with_process<P, D: Deploy<'a>>( self, process: &Process<'_, P>, spec: impl IntoProcessSpec<'a, D>, ) -> DeployFlow<'a, D>
pub fn with_remaining_processes<D: Deploy<'a>, S: IntoProcessSpec<'a, D> + 'a>( self, spec: impl Fn() -> S, ) -> DeployFlow<'a, D>
pub fn with_external<P, D: Deploy<'a>>( self, process: &External<'_, P>, spec: impl ExternalSpec<'a, D>, ) -> DeployFlow<'a, D>
pub fn with_remaining_externals<D: Deploy<'a>, S: ExternalSpec<'a, D> + 'a>( self, spec: impl Fn() -> S, ) -> DeployFlow<'a, D>
pub fn with_cluster<C, D: Deploy<'a>>( self, cluster: &Cluster<'_, C>, spec: impl ClusterSpec<'a, D>, ) -> DeployFlow<'a, D>
pub fn with_remaining_clusters<D: Deploy<'a>, S: ClusterSpec<'a, D> + 'a>( self, spec: impl Fn() -> S, ) -> DeployFlow<'a, D>
pub fn compile<D: Deploy<'a, InstantiateEnv = ()>>(self) -> CompiledFlow<'a>
pub fn deploy<D: Deploy<'a>>( self, env: &mut D::InstantiateEnv, ) -> DeployResult<'a, D>