pub struct EmbeddedNode {
pub fn_name: String,
pub location_key: LocationKey,
}Available on crate feature
build only.Expand description
A trivial node type for embedded deployment. Stores a user-provided function name.
Fields
fn_name: StringThe function name to use in the generated code for this location.
location_key: LocationKeyThe location key for this node, used to register network ports.