pub struct ClosureExpr {
pub expr: DebugExpr,
pub singleton_refs: Vec<(Ident, HydroNode)>,
}Expand description
A closure expression bundled with any singleton references it captures.
When a q!() closure captures a SingletonRef, the reference is recorded here
alongside the closure’s expression. This allows per-closure tracking of singleton
captures, which is important for nodes with multiple closures (e.g. Fold has init and acc).
Fields
expr: DebugExprsingleton_refs: Vec<(Ident, HydroNode)>Implementations
Sourceimpl ClosureExpr
impl ClosureExpr
pub fn new(expr: DebugExpr, singleton_refs: Vec<(Ident, HydroNode)>) -> Self
pub fn deep_clone(&self, seen_tees: &mut SeenSharedNodes) -> Self
pub fn transform_children( &mut self, transform: &mut impl FnMut(&mut HydroNode, &mut SeenSharedNodes), seen_tees: &mut SeenSharedNodes, )
Sourcepub fn emit_tokens(&self, ident_stack: &mut Vec<Ident>) -> TokenStream
Available on crate feature build only.
pub fn emit_tokens(&self, ident_stack: &mut Vec<Ident>) -> TokenStream
build only.Pop singleton ref idents from the stack and rewrite the closure’s token stream,
replacing local singleton ref idents with #dfir_ident references.