pub struct DockerDeployCluster { /* private fields */ }Available on crate features
deploy and docker_deploy only.Expand description
Represents a logical cluster, which can be a variable amount of individual containers.
Implementations
Sourceimpl DockerDeployCluster
impl DockerDeployCluster
Sourcepub fn expose_port(&self, port: u16)
pub fn expose_port(&self, port: u16)
Expose a TCP port on every member of this cluster for external access.
The binary running on this cluster must bind a TcpListener on this port.
This method ensures the port appears in the Docker image’s EXPOSE directives
and is available for endpoint discovery via Self::get_all_tcp_endpoints.