ChannelProtocolVersion

Struct ChannelProtocolVersion 

pub struct ChannelProtocolVersion {
    pub version: u64,
}
Available on crate feature deploy and (crate features docker_runtime or ecs_runtime) only.
Protocol version sent as the second frame, after ChannelMagic.

Incremented when the handshake format changes. The receiver checks this to decide how to deserialize the subsequent ChannelHandshake frame.

Fields

version: u64