pub fn maelstrom_send_response(node_id: &str, client_id: &str, body: Value)Available on (crate features
deploy or sim) and (crate features maelstrom_runtime or maelstrom) only.Expand description
Sends a response to a Maelstrom client via stdout.
This function is meant to be used with for_each on a stream of responses.