BoundedValue

Struct BoundedValue 

pub struct BoundedValue;
A variation of boundedness specific to KeyedSingleton, which indicates that once a key appears, its value is bounded and will never change, but new entries may appear asynchronously