pub trait SingletonBound {
type UnderlyingBound: Boundedness + ApplyMonotoneStream<Proved, Self::StreamToMonotone>;
type StreamToMonotone: SingletonBound<UnderlyingBound = Self::UnderlyingBound>;
// Required method
fn bound_kind() -> SingletonBoundKind;
}Expand description
Required Associated Types
Sourcetype UnderlyingBound: Boundedness + ApplyMonotoneStream<Proved, Self::StreamToMonotone>
type UnderlyingBound: Boundedness + ApplyMonotoneStream<Proved, Self::StreamToMonotone>
The Boundedness that this Singleton would be erased to.
Sourcetype StreamToMonotone: SingletonBound<UnderlyingBound = Self::UnderlyingBound>
type StreamToMonotone: SingletonBound<UnderlyingBound = Self::UnderlyingBound>
The Boundedness of this Singleton if it is produced from a Stream with Self boundedness.
Required Methods
Sourcefn bound_kind() -> SingletonBoundKind
fn bound_kind() -> SingletonBoundKind
Returns the SingletonBoundKind corresponding to this type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".