pub fn state_null<'t, S, L>(tick: &'t Tick<L>) -> StateNullBuilder<'t, S, L>Available on
stageleft_runtime only.Expand description
Creates a stateful cycle without an initial value for use in sliced!.
The tick (which is the source of truth for lifetimes) is bound first, returning a
StateNullBuilder which creates the cycle via StateNullBuilder::build.
On the first iteration, the state will be null/empty. Subsequent iterations receive the value assigned to the mutable binding at the end of the previous iteration.