pub enum EventualConsistency {}Expand description
Eventual consistency is guaranteed across cluster members, which means that at steady-state the live collection will always resolve to the same value across all members of the cluster.