pub struct ClusterIds<'a> {
pub key: LocationKey,
pub _phantom: PhantomData<&'a ()>,
}Expand description
A free variable that resolves to the list of member IDs in a cluster at runtime.
When spliced into a quoted snippet, this provides access to the set of
TaglessMemberIds that belong to the cluster.
Fields
key: LocationKeyThe location key identifying which cluster this refers to.
_phantom: PhantomData<&'a ()>Phantom data binding the lifetime.