pub trait Consistency {
// Required method
fn consistency() -> ClusterConsistency;
}Expand description
A marker trait for levels of consistency that can be guaranteed for a live collection placed across members of a cluster.
Required Methods
Sourcefn consistency() -> ClusterConsistency
fn consistency() -> ClusterConsistency
Gets the runtime enum variant associated with this consistency level.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".