IsCluster

Trait IsCluster 

pub trait IsCluster {
    type Tag;
}
Marker trait implemented by Cluster locations, providing access to the cluster tag type.

Required Associated Types

type Tag

The phantom tag type that distinguishes this cluster from others.

Implementors

Source

impl<C> IsCluster for Cluster<'_, C>

Source

type Tag = C