pub trait DeferTick {
// Required method
fn defer_tick(self) -> Self;
}Expand description
Trait for live collections that can be deferred by one tick.
When a collection implements DeferTick, calling defer_tick delays its
values by one clock cycle. This is primarily used internally to implement
tick-based cycles (Tick::cycle), ensuring that feedback loops advance
by one tick to avoid infinite recursion within a single tick.
Required Methods
Sourcefn defer_tick(self) -> Self
fn defer_tick(self) -> Self
Returns a new collection whose values are delayed by one tick.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".