pub trait NoAtomic: Sealed { }
Marker trait for locations that are not inside an Atomic context.
Atomic
This trait is implemented by top-level locations (Process, Cluster) and by Tick. It is used to constrain APIs that should not be called from within an atomic block.
Process
Cluster
Tick