NoTick

Trait NoTick 

pub trait NoTick: Sealed { }
Marker trait for locations that are not inside a Tick clock domain.

This trait is implemented by top-level locations such as Process and Cluster, as well as Atomic. It is used to constrain APIs that should only be called outside of a tick context (e.g., creating a new tick or sourcing external data).

Implementors

Source

impl<L> NoTick for Atomic<L>

Source

impl<T> NoTick for Cluster<'_, T>

Source

impl<T> NoTick for Process<'_, T>