Embedded

Enum Embedded 

pub enum Embedded {}
Leaves serialization of items to code outside of Hydro.

This serialization backend is only supported by the embedded deployment backend (it will panic on all other backends). The generated network channel exposes the raw element type T to the developer (rather than serialized bytes), so they can perform custom serialization logic outside of the Hydro program for that channel.