LossyDelayedForever

Enum LossyDelayedForever 

pub enum LossyDelayedForever {}
A TCP failure policy that treats dropped messages as indefinitely delayed.

Unlike Lossy, this does not require a NonDet annotation because the output stream is always lower in the partial order than the ideal stream (dropped messages are modeled as infinite delays). The tradeoff is that the output has NoOrder guarantees, imposing stricter conditions on downstream consumers.

When using this mode in the Hydro simulator, you must call .test_safety_only() because the simulator models dropped messages as indefinitely delayed, which only tests safety properties (not liveness).