pub trait TcpFailPolicy: Sealed {
type OrderingGuarantee: Ordering;
// Required method
fn tcp_fault() -> TcpFault;
}Expand description
A failure policy for TCP connections, determining how the transport handles connection failures and what ordering guarantees the output stream provides.
Required Associated Types
Sourcetype OrderingGuarantee: Ordering
type OrderingGuarantee: Ordering
The ordering guarantee provided by this failure policy.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".