pub struct MapFuncAlgebra<OrderPreserving = NotProved>(/* private fields */);Expand description
Algebraic properties for a map function of type T -> U.
Order-preserving means that if the input grows monotonically, the output also grows monotonically.
Implementations
Sourceimpl<O> MapFuncAlgebra<O>
impl<O> MapFuncAlgebra<O>
Sourcepub fn order_preserving(
self,
proof: impl OrderPreservingProof + 'static,
) -> MapFuncAlgebra<Proved>
pub fn order_preserving( self, proof: impl OrderPreservingProof + 'static, ) -> MapFuncAlgebra<Proved>
Marks the function as being order-preserving, with the given proof mechanism.