pub struct SingletonMapFuncAlgebra<OrderPreserving = NotProved, Commutative = NotProved, Idempotent = NotProved>(/* private fields */);Expand description
Algebraic properties for a singleton map function of type T -> U.
Order-preserving means that if the input grows monotonically, the output also grows monotonically.
Implementations
Sourceimpl<O, C, I> SingletonMapFuncAlgebra<O, C, I>
impl<O, C, I> SingletonMapFuncAlgebra<O, C, I>
Sourcepub fn order_preserving(
self,
proof: impl OrderPreservingProof + 'static,
) -> SingletonMapFuncAlgebra<Proved, C, I>
pub fn order_preserving( self, proof: impl OrderPreservingProof + 'static, ) -> SingletonMapFuncAlgebra<Proved, C, I>
Marks the function as being order-preserving, with the given proof mechanism.
Sourcepub fn commutative(
self,
proof: impl CommutativeProof + 'static,
) -> SingletonMapFuncAlgebra<O, Proved, I>
pub fn commutative( self, proof: impl CommutativeProof + 'static, ) -> SingletonMapFuncAlgebra<O, Proved, I>
Marks the function as being commutative, with the given proof mechanism.
Sourcepub fn idempotent(
self,
proof: impl IdempotentProof + 'static,
) -> SingletonMapFuncAlgebra<O, C, Proved>
pub fn idempotent( self, proof: impl IdempotentProof + 'static, ) -> SingletonMapFuncAlgebra<O, C, Proved>
Marks the function as being idempotent, with the given proof mechanism.