ApplyMonotoneKeyedStream

Trait ApplyMonotoneKeyedStream 

pub trait ApplyMonotoneKeyedStream<P, B2: KeyedSingletonBound>: Sealed<P, B2> { }
Marker trait identifying the boundedness of a singleton given a monotonicity property of an aggregation on a keyed stream.

Implementors