ValidCommutativityFor

Trait ValidCommutativityFor 

pub trait ValidCommutativityFor<O: Ordering>: Sealed<O> { }
Marker trait identifying that the commutativity property is valid for the given stream ordering.

Definition (aggregations, |acc: &mut A, item: T|): for any accumulator value and any two items x, y, applying the closure with x then y must produce the same final accumulator as applying it with y then x. This makes the final aggregate independent of the (non-deterministic) arrival order; note that intermediate accumulator values may still differ and must not be observed without a non-determinism annotation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors