pub struct CompiledSimInstance<'a> { /* private fields */ }Available on
stageleft_runtime and crate feature sim only.Expand description
A single instance of a compiled Hydro simulation, which provides methods to interactively execute the simulation, feed inputs, and receive outputs.
Implementations
Sourceimpl<'a> CompiledSimInstance<'a>
impl<'a> CompiledSimInstance<'a>
Sourcepub async fn run_with_scheduler_and_logger<W: Write>(
self,
log_writer: W,
thunk: impl Future<Output = ()>,
)
pub async fn run_with_scheduler_and_logger<W: Write>( self, log_writer: W, thunk: impl Future<Output = ()>, )
Runs the simulation scheduler alongside the given future, until the future completes, reporting the simulation trace to the given logger.
The future always gets to run first; whenever it is blocked (e.g. waiting to receive simulation outputs), the scheduler runs a single step to completion. Steps are atomic with respect to the future: it is re-polled between every pair of scheduler steps, but never while a step is in flight.