pub struct SimAtomicSender<T: Serialize + DeserializeOwned, O: Ordering, R: Retries>(/* private fields */);Available on crate feature
sim only.Expand description
A sender for an atomic input in a simulation.
The send method returns a future that resolves once the atomic tick
containing the sent item has completed processing.
Implementations
Sourceimpl<T: Serialize + DeserializeOwned> SimAtomicSender<T, NoOrder, ExactlyOnce>
impl<T: Serialize + DeserializeOwned> SimAtomicSender<T, NoOrder, ExactlyOnce>
Sourcepub async fn send_many_unordered_atomic<I: IntoIterator<Item = T>>(
&self,
iter: I,
)
pub async fn send_many_unordered_atomic<I: IntoIterator<Item = T>>( &self, iter: I, )
Sends several messages into the atomic input, in non-deterministic order. Returns a future that resolves once all items have been processed through their atomic ticks.
Sourceimpl<T: Serialize + DeserializeOwned> SimAtomicSender<T, TotalOrder, ExactlyOnce>
impl<T: Serialize + DeserializeOwned> SimAtomicSender<T, TotalOrder, ExactlyOnce>
Sourcepub async fn send_atomic(&self, t: T)
pub async fn send_atomic(&self, t: T)
Sends a message into the atomic input and returns a future that resolves once the atomic tick containing this item has completed processing.
Sourcepub async fn send_many_atomic<I: IntoIterator<Item = T>>(&self, iter: I)
pub async fn send_many_atomic<I: IntoIterator<Item = T>>(&self, iter: I)
Sends several messages into the atomic input. Returns a future that resolves once all items have been processed through their atomic ticks.