SimClusterReceiver

Struct SimClusterReceiver 

pub struct SimClusterReceiver<T: Serialize + DeserializeOwned, O: Ordering, R: Retries>(/* private fields */);
Available on crate feature sim only.
A receiver for an external cluster stream in a simulation.

Each received value is a (u32, T) tuple where the u32 is the raw cluster member ID that produced the value.

Implementations

Source

impl<T: Serialize + DeserializeOwned> SimClusterReceiver<T, TotalOrder, ExactlyOnce>

pub fn next(&self, member_id: u32) -> impl use<'_, T> + Future<Output = T>

Receives the next value from a specific cluster member, waiting (and letting the scheduler run any pending simulation work) until one is available. If the simulation becomes quiescent without producing a value, the test fails.

This is safe to use in the middle of a test; to observe the absence of a value, use Self::try_next.

pub async fn try_next(&self, member_id: u32) -> Option<T>

Receives the next value from a specific cluster member, or returns None if no more values can possibly arrive.

If answering requires forcing pending nondeterministic work to run, then afterwards, sending more input and then attempting to receive output will panic. Prefer Self::next when possible.

pub async fn collect<C: Default + Extend<T>>(self, member_id: u32) -> C

Collects all remaining values from a specific cluster member into a collection, waiting until no more values can possibly arrive.

If this has to force pending nondeterministic work to run, it should be the last observation of the test; see SimReceiver::collect.

Source

impl<T: Serialize + DeserializeOwned> SimClusterReceiver<T, NoOrder, ExactlyOnce>

pub fn collect_n_sorted<C: Default + Extend<T> + AsMut<[T]>>( &self, member_id: u32, n: usize, ) -> impl use<'_, T, C> + Future<Output = C>
where T: Ord,

Receives the next n values from a specific cluster member, sorted, waiting (and letting the scheduler run any pending simulation work) until they are available. If the simulation becomes quiescent before n values arrive, the test fails.

Like SimReceiver::next, this is safe to use in the middle of a test.

pub async fn collect_sorted<C: Default + Extend<T> + AsMut<[T]>>( self, member_id: u32, ) -> C
where T: Ord,

Collects all remaining values from a specific cluster member, sorted, waiting until no more values can possibly arrive.

If this has to force pending nondeterministic work to run, it should be the last observation of the test; see SimReceiver::collect.