pub struct EmbeddedInstantiateEnv {
pub inputs: SparseSecondaryMap<LocationKey, Vec<(Ident, Type)>>,
pub outputs: SparseSecondaryMap<LocationKey, Vec<(Ident, Type)>>,
pub network_outputs: SparseSecondaryMap<LocationKey, Vec<(String, bool)>>,
pub network_inputs: SparseSecondaryMap<LocationKey, Vec<(String, bool)>>,
pub membership_streams: SparseSecondaryMap<LocationKey, Vec<LocationKey>>,
}build only.Expand description
Collected embedded input/output registrations, keyed by location.
During compile_network, each HydroSource::Embedded and HydroRoot::EmbeddedOutput
IR node registers its ident, element type, and location key here.
generate_embedded then uses this to add the appropriate parameters
to each generated function.
Fields
inputs: SparseSecondaryMap<LocationKey, Vec<(Ident, Type)>>(ident name, element type) pairs per location key, for inputs.
outputs: SparseSecondaryMap<LocationKey, Vec<(Ident, Type)>>(ident name, element type) pairs per location key, for outputs.
network_outputs: SparseSecondaryMap<LocationKey, Vec<(String, bool)>>Network output port names per location key (sender side of channels). Each entry is (port_name, is_tagged) where is_tagged means the type is (TaglessMemberId, Bytes).
network_inputs: SparseSecondaryMap<LocationKey, Vec<(String, bool)>>Network input port names per location key (receiver side of channels). Each entry is (port_name, is_tagged) where is_tagged means the type is Result<(TaglessMemberId, BytesMut), Error>.
membership_streams: SparseSecondaryMap<LocationKey, Vec<LocationKey>>Cluster membership streams needed per location key. Maps location_key -> vec of cluster LocationKeys whose membership is needed.