Consistency

Trait Consistency 

pub trait Consistency {
    // Required method
    fn consistency() -> ClusterConsistency;
}
A marker trait for levels of consistency that can be guaranteed for a live collection placed across members of a cluster.

Required Methods

fn consistency() -> ClusterConsistency

Gets the runtime enum variant associated with this consistency level.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors