DeferTick

Trait DeferTick 

pub trait DeferTick {
    // Required method
    fn defer_tick(self) -> Self;
}
Trait for live collections that can be deferred by one tick.

When a collection implements DeferTick, calling defer_tick delays its values by one clock cycle. This is primarily used internally to implement tick-based cycles (Tick::cycle), ensuring that feedback loops advance by one tick to avoid infinite recursion within a single tick.

Required Methods

fn defer_tick(self) -> Self

Returns a new collection whose values are delayed by one tick.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, K, V, L> DeferTick for KeyedSingleton<K, V, Tick<L>, Bounded>
where L: Location<'a>,

Source

impl<'a, K, V, L, O: Ordering, R: Retries> DeferTick for KeyedStream<K, V, Tick<L>, Bounded, O, R>
where L: Location<'a>,

Source

impl<'a, T, L> DeferTick for Optional<T, Tick<L>, Bounded>
where L: Location<'a>,

Source

impl<'a, T, L, O: Ordering, R: Retries> DeferTick for Stream<T, Tick<L>, Bounded, O, R>
where L: Location<'a>,