pub struct NetworkingConfig<Tr: ?Sized, S: ?Sized, Name = ()> { /* private fields */ }Expand description
A network channel configuration with T as transport backend and S as the serialization
backend.
Implementations
Sourceimpl<Tr: ?Sized, S: ?Sized> NetworkingConfig<Tr, S>
impl<Tr: ?Sized, S: ?Sized> NetworkingConfig<Tr, S>
Sourceimpl<Tr: ?Sized, N> NetworkingConfig<Tr, NoSer, N>
impl<Tr: ?Sized, N> NetworkingConfig<Tr, NoSer, N>
Sourcepub const fn bincode(self) -> NetworkingConfig<Tr, Bincode, N>
pub const fn bincode(self) -> NetworkingConfig<Tr, Bincode, N>
Configures the network channel to use bincode to serialize items.
Sourceimpl<S: ?Sized> NetworkingConfig<Tcp<()>, S>
impl<S: ?Sized> NetworkingConfig<Tcp<()>, S>
Sourcepub const fn fail_stop(self) -> NetworkingConfig<Tcp<FailStop>, S>
pub const fn fail_stop(self) -> NetworkingConfig<Tcp<FailStop>, S>
Configures the TCP transport to stop sending messages after a failed connection.
Note that the Hydro simulator will not simulate connection failures that impact the
liveness of a program. If an output assertion depends on a fail_stop channel
making progress, that channel will not experience a failure that would cause the test to
block indefinitely. However, any safety issues caused by connection failures will still
be caught, such as a race condition between a failed connection and some other message.
Sourcepub const fn lossy(self, nondet: NonDet) -> NetworkingConfig<Tcp<Lossy>, S>
pub const fn lossy(self, nondet: NonDet) -> NetworkingConfig<Tcp<Lossy>, S>
Configures the TCP transport to allow messages to be lost.
This is appropriate for networks where messages may be dropped, such as when
running under a Maelstrom partition nemesis. Unlike fail_stop, which guarantees
a prefix of messages is delivered, lossy makes no such guarantee.
Non-Determinism
A lossy TCP channel will non-deterministically drop messages during execution.
Sourcepub const fn lossy_delayed_forever(
self,
) -> NetworkingConfig<Tcp<LossyDelayedForever>, S>
pub const fn lossy_delayed_forever( self, ) -> NetworkingConfig<Tcp<LossyDelayedForever>, S>
Configures the TCP transport to treat dropped messages as indefinitely delayed.
This is appropriate for networks where messages may be dropped, such as when
running under a Maelstrom partition nemesis. Unlike Self::lossy, this does
not require a NonDet annotation because the output is always lower in the
partial order than the ideal stream. However, the output stream will have
NoOrder guarantees, imposing stricter conditions on downstream consumers.
Unlike Self::lossy, this mode can easily be simulated in exhaustive mode
without running into fairness issues.
When using this mode in the Hydro simulator, you must call
.test_safety_only() to opt in,
because the simulator models dropped messages as indefinitely delayed, which only
tests safety properties (not liveness).